@@ -1,11 +1,11 @@
 ;;; vscode-dark-plus-theme.el --- Default Visual Studio Code Dark+ theme -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2020 Ian Y.E. Pan
+;; Copyright (C) 2020-2021 Ian Y.E. Pan
 
 ;; Author: Ian Y.E. Pan
 ;; URL: https://github.com/ianpan870102/vscode-dark-plus-emacs-theme
-;; Package-Version: 2.0.0
-;; Package-Revision: 41772165b3b1
+;; Package-Version: 2.1.0
+;; Package-Revision: 37f16729ee19
 
 ;; This program is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -60,6 +60,16 @@
   :type 'boolean
   :group 'dark-plus)
 
+(defcustom vscode-dark-plus-render-line-highlight 'default
+  "Controls rendering of the current line highlight."
+  :type '(radio
+          (const :tag "None" none)
+          (const :tag "Gutter" gutter)
+          (const :tag "Line" line)
+          (const :tag "Gutter and Line" all)
+          (const :tag "Default" default))
+  :group 'dark-plus)
+
 (let ((class '((class color) (min-colors 89)))
       (fg0               "#aeafad")
       (fg1               "#d4d4d4") ; default fg
@@ -81,10 +91,11 @@
       (numeric           "#b5cea8")
       (mode-line-bg      "#007acc")
       (mode-line-bg-dark "#005aa3")
-      (line-num          "#838383")
+      (line-num          "#858585")
+      (line-num-current  "#c6c6c6")
       (builtin           "#c586c0")
       (keyword           "#569cd6")
-      (const             "#4ec9b0")
+      (const             "#569cd6")
       (comment           "#6a9955")
       (doc               "#ce9178")
       (doc-alt           "#888888")
@@ -125,6 +136,9 @@
    `(font-lock-doc-face                       ((,class (:foreground ,doc))))
    `(font-lock-function-name-face             ((,class (:foreground ,func :bold nil))))
    `(font-lock-keyword-face                   ((,class (:bold nil :foreground ,keyword))))
+   `(font-lock-number-face                    ((,class (:foreground ,numeric))))
+   `(font-lock-operator-face                  ((,class (:inherit default))))
+   `(font-lock-punctuation-face               ((,class (:inherit default))))
    `(font-lock-string-face                    ((,class (:foreground ,str))))
    `(font-lock-type-face                      ((,class (:foreground ,type ))))
    `(font-lock-variable-name-face             ((,class (:foreground ,var))))
@@ -135,8 +149,13 @@
    `(region                                   ((,class (:background ,bg-hl :distant-foreground ,fg0 :extend nil))))
    `(secondary-selection                      ((,class (:inherit region))))
    `(highlight                                ((,class (:foreground "#4db2ff" :underline t)))) ; link hover
-   `(hl-line                                  ((,class (:background ,bg3))))
-   `(fringe                                   ((,class (:background nil :foreground ,fg4))))
+   `(hl-line                                  ((,class ,(pcase vscode-dark-plus-render-line-highlight
+                                                          ((or 'line 'all)
+                                                           `(:background ,bg1 :box (:color ,bg3 :line-width (0 . -1))))
+                                                          ('none `(:background ,bg1))
+                                                          ('default `(:background ,bg3))))))
+   `(fill-column-indicator                    ((,class (:foreground "#5a5a5a")))) ; editorRuler.foreground
+   `(fringe                                   ((,class (:background unspecified :foreground ,fg4))))
    `(cursor                                   ((,class (:background ,fg1))))
    `(show-paren-match-face                    ((,class (:background ,warning))))
    `(show-paren-match                         ((t (:foreground ,fg3 :background ,bg4 :bold t))))
@@ -144,19 +163,23 @@
    `(isearch                                  ((,class (:background "#613214"))))
    `(vertical-border                          ((,class (:foreground "black"))))
    `(minibuffer-prompt                        ((,class (:foreground ,ms-bluegreen :weight normal))))
-   `(default-italic                           ((,class (:italic t))))
    `(link                                     ((,class (:foreground "#3794ff"))))
    `(error                                    ((,class (:foreground ,ms-orange))))
    `(warning                                  ((,class (:foreground ,ms-magenta))))
    `(success                                  ((,class (:foreground ,ms-bluegreen))))
    `(dired-directory                          ((t (:inherit (font-lock-keyword-face)))))
-   `(line-number                              ((,class (:foreground ,line-num :background ,bg1))))
-   `(line-number-current-line                 ((,class (:foreground ,fg1 :background nil))))
-   `(header-line                              ((,class (:inherit nil :foreground ,accent :background ,bg4 :box (:line-width -1)))))
+   `(line-number                              ((,class (:inherit default :foreground ,line-num))))
+   `(line-number-current-line                 ((,class (:inherit default :foreground ,line-num-current
+                                                                 ,@(pcase vscode-dark-plus-render-line-highlight
+                                                                     ((or 'gutter 'all)
+                                                                      `(:background ,bg1 :box (:color ,bg3 :line-width (0 . -1))))
+                                                                     ((or 'none 'default)
+                                                                      `(:background ,bg1)))))))
+   `(header-line                              ((,class (:bold nil :foreground ,fg4 :background ,bg3))))
 
    `(mode-line                                ((,class (:bold nil :foreground ,fg4 :background ,mode-line-bg))))
    `(mode-line-inactive                       ((,class (:bold nil :foreground ,fg1 :background ,mode-line-bg-dark))))
-   `(mode-line-buffer-id                      ((,class (:bold nil :foreground ,accent :background nil))))
+   `(mode-line-buffer-id                      ((,class (:bold nil :foreground ,accent :background unspecified))))
    `(mode-line-highlight                      ((,class (:foreground ,keyword :box nil :weight normal))))
    `(mode-line-emphasis                       ((,class (:foreground ,fg1))))
 
@@ -173,9 +196,13 @@
                                                               ,@(when vscode-dark-plus-scale-org-faces (list :height 1.1))))))
    `(org-level-2                              ((,class (:bold nil :foreground ,ms-lightblue))))
    `(org-level-3                              ((,class (:bold nil :foreground ,ms-blue))))
-   `(org-level-4                              ((,class (:bold nil :foreground ,ms-bluegreen))))
-   `(org-code                                 ((,class (:foreground ,fg2))))
-   `(org-hide                                 ((,class (:foreground ,fg4))))
+   `(org-level-4                              ((,class (:bold nil :foreground ,ms-yellow))))
+   `(org-level-5                              ((,class (:bold nil :foreground ,ms-magenta))))
+   `(org-level-6                              ((,class (:bold nil :foreground ,ms-orange))))
+   `(org-level-7                              ((,class (:bold nil :foreground ,ms-lightorange))))
+   `(org-level-8                              ((,class (:bold nil :foreground ,ms-red))))
+   `(org-code                                 ((,class (:foreground ,ms-orange))))
+   `(org-hide                                 ((,class (:foreground ,bg1))))
    `(org-date                                 ((,class (:underline t :foreground ,var) )))
    `(org-footnote                             ((,class (:underline t :foreground ,fg4))))
    `(org-link                                 ((,class (:underline t :foreground ,type ))))
@@ -183,8 +210,8 @@
    `(org-block                                ((,class (:foreground ,fg2 :background ,bg0 :extend t))))
    `(org-quote                                ((,class (:inherit org-block :slant italic))))
    `(org-verse                                ((,class (:inherit org-block :slant italic))))
-   `(org-todo                                 ((,class (,@(when vscode-dark-plus-box-org-todo (list :box '(:line-width 1 :color ,ms-lightred)))
-                                                             :foreground ,ms-lightred :bold nil))))
+   `(org-todo                                 ((,class (,@(when vscode-dark-plus-box-org-todo (list :box `(:line-width 1 :color ,ms-lightred)))
+                                                        :foreground ,ms-lightred :bold nil))))
    `(org-done                                 ((,class (:box (:line-width 1 :color ,ms-lightgreen) :foreground ,ms-lightgreen :bold nil ))))
    `(org-warning                              ((,class (:underline t :foreground ,warning))))
    `(org-agenda-structure                     ((,class (:weight normal :foreground ,fg3 :box (:color ,fg4) :background ,bg3))))
@@ -197,7 +224,7 @@
    `(org-scheduled-today                      ((,class (:foreground ,func :weight normal
                                                                     ,@(when vscode-dark-plus-scale-org-faces (list :height 1.2))))))
    `(org-ellipsis                             ((,class (:foreground ,builtin))))
-   `(org-verbatim                             ((,class (:foreground ,fg4))))
+   `(org-verbatim                             ((,class (:foreground ,ms-lightorange))))
    `(org-document-title                       ((,class (:foreground ,type :bold t
                                                                     ,@(when vscode-dark-plus-scale-org-faces (list :height 1.2)))))) ; title
    `(org-document-info                        ((,class (:foreground ,ms-yellow)))) ; author, date etc.
@@ -256,7 +283,7 @@
    `(icompletep-determined                    ((,class :foreground ,builtin)))
 
    `(slime-repl-inputed-output-face           ((,class (:foreground ,type))))
-   `(trailing-whitespace                      ((,class :foreground nil :background ,warning)))
+   `(trailing-whitespace                      ((,class :foreground unspecified :background ,warning)))
    `(lazy-highlight                           ((,class (:background "#613214"))))
 
    `(undo-tree-visualizer-current-face        ((,class :foreground ,builtin)))
@@ -425,8 +452,8 @@
    `(web-mode-json-key-face                   ((,class (:foreground ,str))))
    `(web-mode-json-context-face               ((,class (:foreground ,str))))
 
-   `(diff-header                              ((t (:foreground ,ms-bluegreen :background nil))))
-   `(diff-file-header                         ((t (:foreground ,fg3 :background nil))))
+   `(diff-header                              ((t (:foreground ,ms-bluegreen :background unspecified))))
+   `(diff-file-header                         ((t (:foreground ,fg3 :background unspecified))))
    `(diff-hunk-header                         ((t (:foreground ,fg4 :background ,bg3))))
    `(diff-added                               ((t (:foreground ,fg2 :background ,ms-green-bg))))
    `(diff-removed                             ((t (:foreground ,fg2 :background ,ms-red-bg))))
@@ -495,12 +522,12 @@
    `(swiper-match-face-4                      ((t (:inherit ivy-minibuffer-match-face-4))))
    `(swiper-line-face                         ((t (:foreground ,fg0 :background ,bg4 :extend t))))
 
-   `(git-gutter:added                         ((t (:background ,vc-g :foreground ,vc-g :weight normal))))
-   `(git-gutter:deleted                       ((t (:background ,vc-r :foreground ,vc-r :weight normal))))
-   `(git-gutter:modified                      ((t (:background ,vc-b :foreground ,vc-b :weight normal))))
-   `(git-gutter-fr:added                      ((t (:background ,vc-g :foreground ,vc-g :weight normal))))
-   `(git-gutter-fr:deleted                    ((t (:background ,vc-r :foreground ,vc-r :weight normal))))
-   `(git-gutter-fr:modified                   ((t (:background ,vc-b :foreground ,vc-b :weight normal))))
+   `(git-gutter:added                         ((t (:foreground ,vc-g :weight normal))))
+   `(git-gutter:deleted                       ((t (:foreground ,vc-r :weight normal))))
+   `(git-gutter:modified                      ((t (:foreground ,vc-b :weight normal))))
+   `(git-gutter-fr:added                      ((t (:foreground ,vc-g :weight normal))))
+   `(git-gutter-fr:deleted                    ((t (:foreground ,vc-r :weight normal))))
+   `(git-gutter-fr:modified                   ((t (:foreground ,vc-b :weight normal))))
 
    `(diff-hl-insert                           ((t (:background ,vc-g :foreground ,vc-g))))
    `(diff-hl-delete                           ((t (:background ,vc-r :foreground ,vc-r))))
@@ -510,8 +537,8 @@
    `(neo-header-face                          ((t (:foreground "#cccccc"))))
    `(neo-banner-face                          ((t (:foreground "#cccccc"))))
    `(neo-root-dir-face                        ((t (:foreground "#cccccc"))))
-   `(neo-file-link-face                       ((t (:foreground "#aaaaaa"))))
-   `(neo-expand-btn-face                      ((t (:foreground "#aaaaaa"))))
+   `(neo-file-link-face                       ((t (:foreground "#cccccc"))))
+   `(neo-expand-btn-face                      ((t (:foreground "#cccccc"))))
 
    `(sml/global                               ((t (:foreground ,fg2 :weight normal))))
    `(sml/filename                             ((t (:foreground ,fg2 :weight normal))))
@@ -530,6 +557,10 @@
    `(highlight-operators-face                 ((t (:inherit default))))
    `(highlight-symbol-face                    ((t (:background "#343a40"))))
 
+   `(highlight-thing                          ((t ,(pcase vscode-dark-plus-render-line-highlight
+                                                     ('default `(:inherit region))
+                                                     (_ `(:background ,bg3))))))
+
    `(window-divider                           ((t (:foreground "gray40"))))
    `(window-divider-last-pixel                ((t (:foreground "gray20"))))
    `(window-divider-first-pixel               ((t (:foreground "gray60"))))
@@ -537,12 +568,34 @@
    `(tree-sitter-hl-face:method.call          ((t (:inherit font-lock-function-name-face))))
    `(tree-sitter-hl-face:function.call        ((t (:inherit font-lock-function-name-face))))
    `(tree-sitter-hl-face:operator             ((t (:inherit default))))
-   `(tree-sitter-hl-face:type.builtin         ((t (:inherit font-lock-keyword-face))))
+   `(tree-sitter-hl-face:constant.builtin     ((t (:inherit font-lock-constant-face))))
    `(tree-sitter-hl-face:number               ((t (:inherit highlight-numbers-number))))
+   `(tree-sitter-hl-face:variable.special     ((t (:inherit font-lock-keyword-face))))
+   `(tree-sitter-hl-face:keyword              ((t (:foreground ,ms-magenta))))
 
-   `(tab-bar-tab-inactive                     ((t (:background ,bg2))))
+   `(lsp-ui-doc-background                    ((t (:background ,bg2))))
+
+   `(font-latex-bold-face                     ((t (:inherit bold))))
+   `(font-latex-italic-face                   ((t (:inherit italic))))
+   `(font-latex-math-face                     ((t (:foreground ,ms-blue))))
+   `(font-latex-sectioning-0-face             ((t (:foreground ,ms-blue))))
+   `(font-latex-sectioning-1-face             ((t (:foreground ,ms-magenta))))
+   `(font-latex-sectioning-2-face             ((t (:foreground ,ms-lightorange))))
+   `(font-latex-sectioning-3-face             ((t (:foreground ,ms-lightblue))))
+   `(font-latex-sectioning-4-face             ((t (:foreground ,ms-lightred))))
+   `(font-latex-sectioning-5-face             ((t (:foreground ,ms-lightgreen))))
+   `(font-latex-script-char-face              ((t (:foreground ,ms-blue))))
+   `(font-latex-string-face                   ((t (:inherit font-lock-string-face))))
+   `(font-latex-warning-face                  ((t (:inherit font-lock-warning-face))))
+   `(font-latex-verbatim-face                 ((t (:inherit org-verbatim))))
+   `(TeX-error-description-error              ((t (:inherit error :bold t))))
+   `(TeX-error-description-warning            ((t (:inherit warning :bold t))))
+   `(TeX-error-description-tex-said           ((t (:inherit success :bold t))))
+
+   `(tab-bar-tab-inactive                     ((t (:background "#2D2D2D" :foreground ,fg0))))
    `(tab-bar-tab                              ((t (:background ,bg1 :foreground ,accent))))
-   `(tab-bar                                  ((t (:background ,bg2))))))
+   `(tab-line                                 ((t (:background ,bg2))))
+   `(tab-bar                                  ((t (:background ,bg1))))))
 
 ;;;###autoload
 (when (and (boundp 'custom-theme-load-path) load-file-name)
